
/* gener.c */
void Distributor(int);
void mla(int *, int *);
void F77_SUB(llist)(int *, int *, int *, int *);
void delete_list_array(int *, int *);
int N_C_R(int, int);
int F77_CALL(allnr)(int *n, int *r, int *j, int *ifault); 


/* hierpart.c */
void hierpart(int *, int*, double *, double *, void *);

/* old_hierpart.c */
/*int main(int, char **);*/

/* xauxil.c */
double Factorial(int);
int Combos(int, int);
BOOLEAN Acquire(int, double *);
void Partition(int, double, double[]);
double ReturnDiff(int, int);

